@@ -1,7 +1,5 @@
-import datetime
-import functools
-from math import sin, cos
 import warnings
+from typing import Union, Iterable, Dict
 
 from astroquery.jplhorizons import Horizons
 import healpy as hp
@@ -17,20 +15,26 @@ TARGET_ALIASES = {
 }
 
 
-@functools.lru_cache
-def get_target_coordinates(target: str, time: datetime.datetime.date) -> np.ndarray:
+def get_target_coordinates(
+    target: str, epochs: Union[float, Iterable, Dict[str, str]],
+) -> np.ndarray:
     """Returns the heliocentric cartesian coordinates of the target.
     
     Parameters
     ----------
-    target : str
+    target
         Name of the target body.
-    time : `datetime.datetime`
-        Date and time at which to get the targets coordinates.
+    epochs : scalar, list-like, or dictionary, optional
+            Either a list of epochs in JD or MJD format or a dictionary
+            defining a range of times and dates; the range dictionary has to
+            be of the form {``'start'``:'YYYY-MM-DD [HH:MM:SS]',
+            ``'stop'``:'YYYY-MM-DD [HH:MM:SS]', ``'step'``:'n[y|d|m|s]'}.
+            Epoch timescales depend on the type of query performed: UTC for
+            ephemerides queries, TDB for element queries, CT for vector queries.
+            If no epochs are provided, the current time is used.
 
     Returns
     -------
-    `numpy.ndarray`
         Heliocentric cartesian coordinates of the target.
     """
 
@@ -38,25 +42,25 @@ def get_target_coordinates(target: str, time: datetime.datetime.date) -> np.ndar
         target = TARGET_ALIASES[target.lower()]
     else:
         warnings.warn(
-            'The Zodiacal Emission model is only valid in the immediate '
-            'surroundings of the earth'
+            'The K98 model is only valid when observed from a near earth orbit'
         )
 
-    stop = time + datetime.timedelta(days=1)
-    start = time
-    epochs = dict(start=str(start), stop=str(stop), step='1d')
-    
-    query = Horizons(id=target, id_type='majorbody', location='c@sun', epochs=epochs)
+    query = Horizons(
+        id=target, id_type='majorbody', location='c@sun', epochs=epochs
+    )
     ephemerides = query.ephemerides()
 
-    R = ephemerides['r'][0]
-    lon, lat = ephemerides['EclLon'][0], ephemerides['EclLat'][0]
+    R = ephemerides['r'].value
+    lon, lat = ephemerides['EclLon'].value, ephemerides['EclLat'].value
+    lon, lat = np.deg2rad(lon), np.deg2rad(lat)
 
-    x = R * cos(lat) * cos(lon)
-    y = R * cos(lat) * sin(lon)
-    z = R * sin(lat)
+    x = R * np.cos(lat) * np.cos(lon)
+    y = R * np.cos(lat) * np.sin(lon)
+    z = R * np.sin(lat)
     
-    return np.array([[x], [y], [z]])
+    coordinates = np.stack((x,y,z), axis=1)
+
+    return coordinates
 
 
 def change_coordinate_system(
@@ -64,17 +68,18 @@ def change_coordinate_system(
 ) -> np.ndarray:
     """Rotates a map from coordinate system to another using healpy.Rotator
     
-    Paramters
-    ---------
-    input_map : `numpy.ndarray`
+    Parameters
+    ----------
+    input_map
         Map to rotate.
-    coord_out : str
+    coord_out
         Coordinate system of the output_map.
-    coord_in : str
+    coord_in
         Coordinate system of the input_map.
+
     Returns
     -------
-    output_map : `numpy.ndarray`
+    output_map
         Rotated map.
     """
 
