@@ -11,15 +11,12 @@ class IntegrationConfig:
     
     Attributes
     ----------
-    R_min : float
-        Minimum distance from the observer for which to evaluate the 
-        dust density.
-    R_max : float 
+    R_max
         Maximum distance from the observer for which to evaluate the 
         dust density.
-    n : int
+    n
         Number of shells for which to evaluate the dust density.
-    integator : func
+    integator
         Function which performs the integration.
     """
 
@@ -43,6 +40,15 @@ class IntegrationConfig:
 
 _CUT_OFF = 6
 
+DEFAULT = {
+    'cloud': IntegrationConfig(R_max=_CUT_OFF, n=250),
+    'band1': IntegrationConfig(R_max=_CUT_OFF, n=50),
+    'band2': IntegrationConfig(R_max=_CUT_OFF, n=50),
+    'band3': IntegrationConfig(R_max=_CUT_OFF, n=50),
+    'ring': IntegrationConfig(R_max=2.25, n=50),
+    'feature': IntegrationConfig(R_max=1, n=50),
+}
+
 HIGH = {
     'cloud': IntegrationConfig(R_max=_CUT_OFF, n=500),
     'band1': IntegrationConfig(R_max=_CUT_OFF, n=500),
@@ -52,11 +58,8 @@ HIGH = {
     'feature': IntegrationConfig(R_max=1, n=200),
 }
 
-DEFAULT = {
-    'cloud': IntegrationConfig(R_max=_CUT_OFF, n=250),
-    'band1': IntegrationConfig(R_max=_CUT_OFF, n=50),
-    'band2': IntegrationConfig(R_max=_CUT_OFF, n=50),
-    'band3': IntegrationConfig(R_max=_CUT_OFF, n=50),
-    'ring': IntegrationConfig(R_max=2.25, n=50),
-    'feature': IntegrationConfig(R_max=1, n=50),
+
+INTEGRATION_CONFIGS = {
+    'default' : DEFAULT,
+    'high' : HIGH,
 }
\ No newline at end of file
